# frozen_string_literal: true

require 'jekyll/page'
require_relative 'helper'
require_relative 'notifier'

module Jekyll
  module ActivityPub
    # Points to site's author
    class WebFinger < Jekyll::Page
      include Helper

      # Initialize with default data
      #
      # @param :site [Jekyll::Site]
      # @param :actor [Jekyll::ActivityPub::Actor]
      # @param :base [String]
      # @param :dir [String]
      # @param :name [String]
      def initialize(site, actor, base = '', dir = '.well-known', name = 'webfinger')
        @context = StubContext.new(registers: { site: site })
        @actor = actor

        super(site, base, dir, name)

        Notifier.actor = "@#{username}@#{hostname}"

        # Set the actor profile in yet another format (no leading @)
        site.config['activity_pub_profile'] = "#{username}@#{hostname}"

        trigger_hooks :post_init
      end

      def read_yaml(*)
        self.data = {
          'subject' => "acct:#{username}@#{hostname}",
          'aliases' => [],
          'links' => [
            {
              'rel' => 'self',
              'type' => 'application/activity+json',
              'href' => absolute_url(@actor.url)
            }
          ]
        }
      end

      # The webfinger file is expected to be at this location always
      #
      # @return [String]
      def permalink
        '.well-known/webfinger'
      end
    end
  end
end
